unit UPageTV;

{$mode delphi}

interface

uses
  Classes, SysUtils, FileUtil, UWebPage, UHTTPServer, USqlDatabase, UHtmlClasses,
  UUtils;

type

  { TWebPageTV }

  TWebPageTV = class(TWebPage)
    procedure DataModuleProduce(HandlerData: THTTPHandlerData);
  private
    procedure HandleList(HandlerData: THTTPHandlerData);
    procedure HandlePlaylist(HandlerData: THTTPHandlerData);
  public
    { public declarations }
  end;

var
  WebPageTV: TWebPageTV;

implementation

{$R *.lfm}

uses
  UCore;

{ TWebPageTV }

procedure TWebPageTV.DataModuleProduce(HandlerData: THTTPHandlerData);
var
  PageName: string;
begin
  with TWebSession(HandlerData) do begin
    if Request.Path.Count > 1 then PageName := Request.Path[1]
      else PageName := '';
    with HtmlDocument.Body do begin
      if PageName = '' then PageName := 'list';
      if PageName = 'list' then HandleList(HandlerData)
        else if PageName = 'playlist' then HandlePlaylist(HandlerData);
    end;
  end;
end;

procedure TWebPageTV.HandleList(HandlerData: THTTPHandlerData);
var
  I: Integer;
  DbRows: TDbRows;
  TuneUp: string;
begin
  with TWebSession(HandlerData) do begin
    LoadUserInfo;
    with HtmlDocument.Body, THtmlString(SubItems.AddNew(THtmlString.Create)) do begin
      Text := 'Stažení přehrávače: <a href="http://www.videolan.org/vlc/">VLC Media Player</a><br/>' +
    'Seznam všech kanálů do přehrávače: <a href="playlist/">Playlist</a><br/>' +
    'Zobrazení playlistu ve VLC lze provést pomocí menu <strong>View - Playlist</strong> nebo klávesové zkratky CTRL+L<br/>' +
    '<br/>' +
    '<div align="center"><strong>Výpis kanálů:</strong><br>';
      Text := Text + '<table class="WideTable">' +
      '<tr><th>Název</th><th>Jazyk</th><th>Kategorie</th><th>Ladění</th></tr>';
      try
        DbRows := TDbRows.Create;
        Database.Query(DbRows, 'SELECT * FROM `TV` WHERE (`Stream` <> "") OR (`StreamWeb` <> "") ORDER BY `Name` DESC');
        for I := 0 to DbRows.Count - 1 do
        with DbRows[I] do begin
          TuneUp := '&nbsp;';
          if Values['StreamWeb'] <> '' then
            TuneUp := MakeLink('Naladit', Values['StreamWeb']);
          if Values['Stream'] <> '' then
            TuneUp := MakeLink('Naladit', NavigationLink('/tv/playlist?id=' + Values['ShortName']));
          Text := Text + '<tr><td>' + MakeLink(Values['Name'], Values['Homepage']) +
            '</td><td align="center">' +
            Values['Language'] + '</td><td align="center">' + Values['Category'] + '</td>' +
            '<td>' + TuneUp + '</td></tr>';
        end;
        Text := Text + '</table></div><br/>';

        Text := Text + 'Originální informace o televizi: <a href="http://tv.hovnet.czf/">HovNet televize</a><br/>';
        Text := Text + 'Další online TV na webu: <a href="http://spustit.cz">Spustit.cz</a><br/>';
        Text := Text + 'Další online TV na webu: <a href="http://www.tvinfo.cz/live/televize/evropa/cz">TV info</a><br/>';

      finally
        DbRows.Free;
      end;
      Text := Text + '</table>';
    end;
    GeneratePage(Self);
  end;
end;

procedure TWebPageTV.HandlePlaylist(HandlerData: THTTPHandlerData);
var
  DbRows: TDbRows;
  I: Integer;
  Text: string;
begin
  with TWebSession(HandlerData) do begin
      Response.Headers.Add('Content-Type', 'audio/mpegurl');
      Response.Headers.Add('Content-Disposition', 'attachment; filename=playlist.m3u');
      try
        DbRows := TDbRows.Create;

      Text := '#EXTM3U' + LineEnding;
      if Request.Query.SearchKey('id') <> -1 then begin
        Database.Select(DbRows, 'TV', '*', ' (`Stream` <> "") AND (`ShortName`="' + Database.EscapeString(Request.Query.Values['id']) + '") ');
        if DbRows.Count > 0 then begin
          Text := Text + '#EXTINF:0,' + DbRows[0].Values['Name'] + LineEnding
          + DbRows[0].Values['Stream'] + LineEnding;
        end;
      end else begin
        Database.Select(DbRows, 'TV', '*', ' (`Stream` <> "") ORDER BY `Name` ');
        for I := 0 to DbRows.Count - 1 do begin
          Text := Text + '#EXTINF:0,' + DbRows[I].Values['Name'] + LineEnding
          + DbRows[I].Values['Stream'] + LineEnding;
        end;
      end;
      Response.Content.WriteString(Text);

      finally
        DbRows.Free;
      end
  end;
end;

end.

