unit UUserControlPage;

{$mode delphi}

interface

uses
  Classes, SysUtils, FileUtil, UWebPage, UHTTPServer, UHtmlClasses, UXmlClasses,
  UWebObjects;

type

  { TUserControlPage }

  TUserControlPage = class(TWebPage)
    procedure DataModuleProduce(HandlerData: THTTPHandlerData);
  private
    procedure HandleLogin(HandlerData: THTTPHandlerData);
    procedure HandleRegistration(HandlerData: THTTPHandlerData);
    procedure HandleLogout(HandlerData: THTTPHandlerData);
    procedure HandleProfile(HandlerData: THTTPHandlerData);
  public
    { public declarations }
  end; 

var
  UserControlPage: TUserControlPage;

implementation

{$R *.lfm}

uses
  UCore, UUtils, UUser;

  { TUserControlPage }

procedure TUserControlPage.DataModuleProduce(HandlerData: THTTPHandlerData);
var
  PageName: string;
  NewForm: TQueryForm;
  NewGroup: TQueryFormGroup;
  NewItem: TQueryFormItem;
begin
  with TWebSession(HandlerData) do begin
    if Request.Path.Count > 1 then PageName := Request.Path[1]
      else PageName := '';
    with HtmlDocument.Body do begin
      LoadUserInfo;
      if PageName = '' then PageName := 'prihlaseni';
      if PageName = 'prihlaseni' then HandleLogin(HandlerData)
        else if PageName = 'registrace' then HandleRegistration(HandlerData)
        else if PageName = 'odhlaseni' then HandleLogout(HandlerData)
        else if PageName = 'profil' then HandleProfile(HandlerData);
    end;
    GeneratePage(Self);
  end;
end;

procedure TUserControlPage.HandleLogin(HandlerData: THTTPHandlerData);
var
  Form: TQueryForm;
  UserId: Integer;
begin
  with TWebSession(HandlerData), Core, HtmlDocument.Body do begin
    Form := TQueryForm.Create;
    with Form do begin
      Title := 'Přihlášení';
      ClassId := 'WideTable';
      //Action.AsString := '/dev/zdechovnet/trunk/serverinfoo';
      with AddNewGroup do begin
        Title := '';
        with AddNewItem do begin
          Caption := 'Jméno';
          Name := 'UserName';
          Hint := 'Zadejte vaše přihlašovací jméno';
          Required := True;
        end;
        with AddNewItem do begin
          Caption := 'Heslo';
          Name := 'Password';
          Hint := 'Zadejte vaše heslo';
          Required := True;
          ItemType := fitPassword;
        end;
      end;
      with AddNewAction do begin
        Caption := 'Přihlásit';
        Action := 'Login';
      end;
    end;
    if HandlerData.Request.Post.SearchKey('Login') <> -1 then begin
      Form.Load(HandlerData.Request.Post);
      with THtmlString(SubItems.AddNew(THtmlString.Create)) do
        Text := 'Přihlášení uživatele: ' + TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value;
      UserId := User.GetIdByNamePassword(TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value,
        TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Password').Value.Value);
      if UserId = -1 then begin
        with THtmlString(SubItems.AddNew(THtmlString.Create)) do
          Text := '<br/>Chybné jméno nebo heslo';
      end else UserOnline.Login(UserId);
      Form.Free;
    end else
      SubItems.AddNew(Form);
  end;
end;

procedure TUserControlPage.HandleRegistration(HandlerData: THTTPHandlerData);
var
  Form: TQueryForm;
  UserId: Integer;
begin
  with TWebSession(HandlerData), Core, HtmlDocument.Body do begin
    Form := TQueryForm.Create;
    with Form do begin
      Title := 'Registrace nového účtu';
      ClassId := 'WideTable';
      with AddNewGroup do begin
        Title := '';
        with AddNewItem do begin
          Caption := 'Jméno';
          Name := 'UserName';
          Hint := 'Zadejte vaše přihlašovací jméno';
          Required := True;
        end;
        with AddNewItem do begin
          Caption := 'Email';
          Name := 'Email';
          Hint := 'Zadejte vaši elektronickou poštovní schránku';
          Required := True;
        end;
        with AddNewItem do begin
          Caption := 'Heslo';
          Name := 'Password';
          Hint := 'Zadejte vaše heslo';
          Required := True;
          ItemType := fitPassword;
        end;
        with AddNewItem do begin
          Caption := 'Ověření hesla';
          Name := 'PasswordConfirm';
          Hint := 'Zadejte znovu vaše heslo pro ověření';
          Required := True;
          ItemType := fitPassword;
        end;
      end;
      with AddNewAction do begin
        Caption := 'Registrovat';
        Action := 'Register';
      end;
    end;
    if HandlerData.Request.Post.SearchKey('Register') <> -1 then
    with HandlerData.Request do begin
      Form.Load(HandlerData.Request.Post);
      with THtmlString(SubItems.AddNew(THtmlString.Create)) do
        Text := 'Registrace uživatele: ' + TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value;
      User.Add(TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value,
        TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Password').Value.Value,
        TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Email').Value.Value);
      UserId := User.GetIdByNamePassword(TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value,
        TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Password').Value.Value);
      if UserId <> -1 then UserOnline.Login(UserId);
      Form.Free;
    end else SubItems.AddNew(Form);
  end;
end;

procedure TUserControlPage.HandleLogout(HandlerData: THTTPHandlerData);
begin
  with TWebSession(HandlerData), Core, HtmlDocument.Body do begin
    UserOnline.Logout;
    with THtmlString(SubItems.AddNew(THtmlString.Create)) do
      Text := 'Uživatel odhlášen';
  end;
end;

procedure TUserControlPage.HandleProfile(HandlerData: THTTPHandlerData);
var
  Form: TQueryForm;
begin
  with TWebSession(HandlerData), HtmlDocument.Body do begin
    Form := TQueryForm.Create;
    with Form do begin
      Title := 'Nastavení profilu';
      ClassId := 'WideTable';
      with AddNewGroup do begin
        Title := '';
        with AddNewItem do begin
          Caption := 'Jméno';
          Name := 'UserName';
          Hint := 'Zadejte vaše přihlašovací jméno';
          Required := True;
          Value.Value := User.Name;
        end;
        with AddNewItem do begin
          Caption := 'Heslo';
          Name := 'Password';
          Hint := 'Zadejte vaše heslo';
          Required := True;
          ItemType := fitPassword;
        end;
        with AddNewItem do begin
          Caption := 'Email';
          Name := 'Email';
          Hint := 'Zadejte vaši emailovou adresu';
          Required := True;
          ItemType := fitText;
          Value.Value := User.Email;
        end;
        with AddNewItem do begin
          Caption := 'Celé jméno';
          Name := 'FullName';
          Hint := 'Zadejte vaše celé jméno';
          Required := False;
          ItemType := fitText;
          Value.Value := User.FullName;
        end;
      end;
      with AddNewAction do begin
        Caption := 'Uložit';
        Action := 'Save';
      end;
    end;
    if HandlerData.Request.Post.SearchKey('Save') <> -1 then
    with HandlerData.Request do begin
      Form.Load(HandlerData.Request.Post);
      with THtmlString(SubItems.AddNew(THtmlString.Create)) do
        Text := 'Profil uživatele: ' + TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value + ' uložen';
      User.Name := TQueryFormGroup(Form.Groups[0]).Rows.FindByName('UserName').Value.Value;
      User.FullName := TQueryFormGroup(Form.Groups[0]).Rows.FindByName('FullName').Value.Value;
      User.Email := TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Email').Value.Value;
      User.Save;
      Form.Free;
    end else SubItems.AddNew(Form);
  end;
end;

end.

